==> pochy-0.1.6-src.tar.gz: pochy-0.1.6-src/MainFrm.h <==
// MainFrm.h : CMainFrame NX̐錾уC^[tFCX̒`܂B
//
/////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_MAINFRM_H__B0C245C8_42EA_11D5_B88C_00008659960F__INCLUDED_)
#define AFX_MAINFRM_H__B0C245C8_42EA_11D5_B88C_00008659960F__INCLUDED_

#include <afxcview.h>
#include "MultiPartView.h"
#include "ProgDialog.h"
#include "SummaryView.h"
#include "AccountView.h"
#include "FolderView.h"
#include "TextView.h"
#include "NotifyIcon.h"

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

class CMainFrame : public CFrameWnd
{
	
protected: // VACY@\݂̂쐬܂B
	CMainFrame();
	DECLARE_DYNCREATE(CMainFrame)

// Agr[g
public:

// Iy[V
public:

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CMainFrame)
	public:
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	protected:
	virtual BOOL OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext);
	virtual LRESULT WindowProc(UINT message, WPARAM wParam, LPARAM lParam);
	//}}AFX_VIRTUAL

// Cve[V
public:
	void StopTaskTrayAnimation();
	void StartTaskTrayAnimation();
	BOOL m_button_gpg_dec;
	BOOL m_button_info;
	BOOL m_button_transfer;
	BOOL m_button_reply;
	void GetStatusBarProgress(int &current, int &upper);
	CString GetStatusBarText();
	void SetStatusBarProgress(int current, int upper);
	void UpdateButton(BOOL b, CString account);
	void HideMultiPartView(BOOL b);
	void ReArrangeSplit();
	void SwitchView();
	CSummaryView* m_pListV;
	CAccountView* m_pAcntV;
	CFolderView* m_pTreeV;
	CTextView* m_pTextV;
	CMultiPartView* m_pMultiV;
	CSplitterWnd m_wndSplitV;
	CSplitterWndEx m_wndSplitH;
	CSplitterWndEx m_wndSplitT2;
	CSplitterWndEx m_wndSplitT;
	BOOL m_flag;
	CProgressCtrl m_progress;
	BOOL Char(UINT nChar);
	void SetStatusBarText(int pane, LPCSTR buf);
	BOOL CreateToolbar();
	virtual ~CMainFrame();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif
private:
	int m_tasktray_animation_num;
	CNotifyIcon m_notifyIcon;
	BOOL m_multipart_hide;

protected:  // Rg[ o[po
	CToolBar    m_wndToolBar;
	CStatusBar  m_wndStatusBar;

// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CMainFrame)
	afx_msg LRESULT OnNotifyIcon(WPARAM wParam, LPARAM lParam);
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnFetchmail();
	afx_msg void OnUpdateFetchmail(CCmdUI* pCmdUI);
	afx_msg void OnUpdateRetrieve(CCmdUI* pCmdUI);
	afx_msg void OnTransfer();
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnUpdateReply(CCmdUI* pCmdUI);
	afx_msg void OnGpgDec();
	afx_msg void OnGpg();
	afx_msg void OnUpdateGpgDec(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGpg(CCmdUI* pCmdUI);
	afx_msg void OnRetrieve();
	afx_msg void OnDestroy();
	afx_msg void OnSetting();
	afx_msg void OnReply();
	afx_msg void OnDraft();
	afx_msg void OnAddress();
	afx_msg void OnUpdateTransfer(CCmdUI* pCmdUI);
	afx_msg void OnInfo();
	afx_msg void OnUpdateInfo(CCmdUI* pCmdUI);
	afx_msg void OnUpdateSetting(CCmdUI* pCmdUI);
	afx_msg void OnToolbarDropDown(NMTOOLBAR* pnmh, LRESULT* plRes);
	afx_msg void OnReplyQuotation();
	afx_msg void OnReplyNoQuotation();
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnSettingGeneral();
	afx_msg void OnSettingAccount();
	afx_msg void OnDisplayHeader();
	afx_msg void OnDisplayRawMail();
	afx_msg void OnSettingFilter();
	afx_msg void OnSettingNewAccount();
	afx_msg void OnTransferQuotation();
	afx_msg void OnGpgKeyManagement();
	afx_msg void OnClose();
	afx_msg BOOL OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct);
	afx_msg void OnSysCommand(UINT nID, LPARAM lParam);
	//}}AFX_MSG
	afx_msg void OnProgCreate();
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MAINFRM_H__B0C245C8_42EA_11D5_B88C_00008659960F__INCLUDED_)

==> pochy-0.1.7a-src.tar.gz: pochy-0.1.7a-src/MainFrm.h <==
// MainFrm.h : CMainFrame NX̐錾уC^[tFCX̒`܂B
//
/////////////////////////////////////////////////////////////////////////////

#if !defined(AFX_MAINFRM_H__B0C245C8_42EA_11D5_B88C_00008659960F__INCLUDED_)
#define AFX_MAINFRM_H__B0C245C8_42EA_11D5_B88C_00008659960F__INCLUDED_

#include <afxcview.h>
#include "MultiPartView.h"
#include "ProgDialog.h"
#include "SummaryView.h"
#include "AccountView.h"
#include "FolderView.h"
#include "TextView.h"
#include "HeaderView.h"
#include "NotifyIcon.h"

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

class CMainFrame : public CFrameWnd
{
	
protected: // VACY@\݂̂쐬܂B
	CMainFrame();
	DECLARE_DYNCREATE(CMainFrame)

// Agr[g
public:

// Iy[V
public:

// I[o[Ch
	// ClassWizard ͉z֐̃I[o[Ch𐶐܂B
	//{{AFX_VIRTUAL(CMainFrame)
	public:
	virtual BOOL PreCreateWindow(CREATESTRUCT& cs);
	protected:
	virtual BOOL OnCreateClient(LPCREATESTRUCT lpcs, CCreateContext* pContext);
	virtual LRESULT WindowProc(UINT message, WPARAM wParam, LPARAM lParam);
	//}}AFX_VIRTUAL

// Cve[V
public:
	void HideHeaderView(BOOL b);
	void StopTaskTrayAnimation();
	void StartTaskTrayAnimation();
	BOOL m_button_gpg_dec;
	BOOL m_button_info;
	BOOL m_button_transfer;
	BOOL m_button_reply;
	void GetStatusBarProgress(int &current, int &upper);
	CString GetStatusBarText();
	void SetStatusBarProgress(int current, int upper);
	void UpdateButton(BOOL b, CString account);
	void HideMultiPartView(BOOL b);
	void ReArrangeSplit();
	void SwitchView();
	CSummaryView* m_pListV;
	CAccountView* m_pAcntV;
	CFolderView* m_pTreeV;
	CTextView* m_pTextV;
	CHeaderView* m_pHeadV;
	CMultiPartView* m_pMultiV;
	CSplitterWnd m_split_left_right;
	CSplitterWndEx m_split_multi_others;
	CSplitterWndEx m_split_summary_others;
	CSplitterWndEx m_split_account_folder;
	CSplitterWndEx m_split_header_text;
	BOOL m_flag;
	CProgressCtrl m_progress;
	BOOL Char(UINT nChar);
	void SetStatusBarText(int pane, LPCSTR buf);
	BOOL CreateToolbar();
	virtual ~CMainFrame();
#ifdef _DEBUG
	virtual void AssertValid() const;
	virtual void Dump(CDumpContext& dc) const;
#endif
private:
	int m_tasktray_animation_num;
	CNotifyIcon m_notifyIcon;
	BOOL m_multipart_hide;

protected:  // Rg[ o[po
	CToolBar    m_wndToolBar;
	CStatusBar  m_wndStatusBar;

// ꂽbZ[W }bv֐
protected:
	//{{AFX_MSG(CMainFrame)
	afx_msg LRESULT OnNotifyIcon(WPARAM wParam, LPARAM lParam);
	afx_msg int OnCreate(LPCREATESTRUCT lpCreateStruct);
	afx_msg void OnFetchmail();
	afx_msg void OnUpdateFetchmail(CCmdUI* pCmdUI);
	afx_msg void OnUpdateRetrieve(CCmdUI* pCmdUI);
	afx_msg void OnTransfer();
	afx_msg void OnSize(UINT nType, int cx, int cy);
	afx_msg void OnUpdateReply(CCmdUI* pCmdUI);
	afx_msg void OnGpgDec();
	afx_msg void OnGpg();
	afx_msg void OnUpdateGpgDec(CCmdUI* pCmdUI);
	afx_msg void OnUpdateGpg(CCmdUI* pCmdUI);
	afx_msg void OnRetrieve();
	afx_msg void OnDestroy();
	afx_msg void OnSetting();
	afx_msg void OnReply();
	afx_msg void OnDraft();
	afx_msg void OnAddress();
	afx_msg void OnUpdateTransfer(CCmdUI* pCmdUI);
	afx_msg void OnInfo();
	afx_msg void OnUpdateInfo(CCmdUI* pCmdUI);
	afx_msg void OnUpdateSetting(CCmdUI* pCmdUI);
	afx_msg void OnToolbarDropDown(NMTOOLBAR* pnmh, LRESULT* plRes);
	afx_msg void OnReplyQuotation();
	afx_msg void OnReplyNoQuotation();
	afx_msg void OnTimer(UINT nIDEvent);
	afx_msg void OnSettingGeneral();
	afx_msg void OnSettingAccount();
	afx_msg void OnDisplayHeader();
	afx_msg void OnDisplayRawMail();
	afx_msg void OnSettingFilter();
	afx_msg void OnSettingNewAccount();
	afx_msg void OnTransferQuotation();
	afx_msg void OnGpgKeyManagement();
	afx_msg void OnClose();
	afx_msg BOOL OnCopyData(CWnd* pWnd, COPYDATASTRUCT* pCopyDataStruct);
	afx_msg void OnSysCommand(UINT nID, LPARAM lParam);
	//}}AFX_MSG
	afx_msg void OnProgCreate();
	DECLARE_MESSAGE_MAP()
};

/////////////////////////////////////////////////////////////////////////////

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ ͑Os̒Oɒǉ̐錾}܂B

#endif // !defined(AFX_MAINFRM_H__B0C245C8_42EA_11D5_B88C_00008659960F__INCLUDED_)
